"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.herokuLogTransformer = exports.parseHerokuAppLogLine = exports.cleanHerokuLogLine = exports.isHerokuAppLogLine = exports.isHerokuLogLine = void 0;
const stream_1 = require("stream");
const constants_1 = require("./constants");
const isHerokuLogLine = (line, regex = constants_1.HEROKU_LOG_REGEX) => new RegExp(regex).test(line);
exports.isHerokuLogLine = isHerokuLogLine;
const isHerokuAppLogLine = (line, regex = constants_1.HEROKU_LOG_REGEX, dyno = 'web') => {
    const result = new RegExp(regex).exec(line);
    const herokuPrefix = result?.length ? result[0] : '';
    return herokuPrefix.includes('app') && herokuPrefix.includes(dyno);
};
exports.isHerokuAppLogLine = isHerokuAppLogLine;
const cleanHerokuLogLine = (line, regex = constants_1.HEROKU_LOG_REGEX) => line.trim().replaceAll(constants_1.ASCII_COLORS_REGEX, '').replaceAll(regex, '').trim();
exports.cleanHerokuLogLine = cleanHerokuLogLine;
const parseHerokuAppLogLine = (line, regex = constants_1.HEROKU_LOG_REGEX, dyno = 'web') => {
    const isHerokuLog = (0, exports.isHerokuLogLine)(line, regex);
    if (!isHerokuLog) {
        return JSON.parse(line);
    }
    const isHerokuAppLog = (0, exports.isHerokuAppLogLine)(line, regex, dyno);
    const cleanLine = isHerokuAppLog ? (0, exports.cleanHerokuLogLine)(line, regex) : null;
    return isHerokuAppLog ? JSON.parse(cleanLine) : null;
};
exports.parseHerokuAppLogLine = parseHerokuAppLogLine;
exports.herokuLogTransformer = new stream_1.Transform({
    autoDestroy: true,
    objectMode: true,
    transform(chunk, encoding, callback) {
        this.push(`${JSON.stringify(chunk)}\n`);
        callback();
    },
});
//# sourceMappingURL=utils.js.map